matcher

package
v0.0.0-...-1b4c788 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 6, 2015 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package matcher providers implementations for most basic AMQ match strategies.

Index

Constants

This section is empty.

Variables

var Direct = New("direct", directMatchFunc)

Direct matcher matches if both, message routing key and binding key are equal.

var Fanout = New("fanout", fanoutMatchFunc)

Fanout matcher always matches

var Topic = New("topic", topicMatchFunc)

Topic matcher matches when routing key matches binding pattern, see AMQP specification for detailed information. There is no need to rewrite all rules here.

Functions

func New

func New(name string, fn func(amq.Message, *amq.Binding) bool) amq.Matcher

New returns Matcher implementation that supports comparision through equality operator `==`

Types

This section is empty.

Jump to